@@ -5,17 +5,25 @@ class BaseCreator:
     def create(self, data):
         raise NotImplementedError
 
+    def perform_data(self, data):
+        new_data = data.copy()
+        new_data[self.source_obj.__class__.__name__.lower()] = self.source_obj
+        new_data[f'{self.source_obj.__class__.__name__.lower()}_id'] = self.source_obj.id
+        return new_data
+
 
 class SerializerCreator(BaseCreator):
     def __init__(self, serializer_class, context, **kwargs):
         self.serializer_class = serializer_class
         self.context = context
         self.kwargs = kwargs
+        self.source_obj = None
 
     def get_serializer(self, *args, **kwargs):
         return self.serializer_class(*args, **kwargs)
 
     def create(self, data):
+        data = self.perform_data(data)
         serializer = self.get_serializer(context=self.context, data=data, many=isinstance(data, list))
         if serializer.is_valid():
             obj = serializer.save()
@@ -28,10 +36,11 @@ class ModelCreator(BaseCreator):
         self.model = model
 
     def create(self, data):
+        data = self.perform_data(data)
         try:
             if isinstance(data, list):
                 for d in data:
-                    obj = self.model.objects.create(**d)
+                    self.model.objects.create(**d)
             else:
                 self.model.objects.create(**data)
             return True
