@@ -9,7 +9,7 @@ class NestedCreaterSerializer(serializers.ModelSerializer):
         for field in getattr(self.Meta, 'relations_create', []):
             if field.__class__.__name__ == 'NestedCreate':
                 request_data = self.context['request'].data.get(field.source).copy()
-                request_data.update({field.source: obj})
+                field.source_obj = obj
                 field.set_data(request_data)
                 field.is_valid()
                 field.create()
